@@ -47,6 +47,23 @@ GtkAccelGroup *accel_group;
 int initHeight = 550, initWidth = 300;
 char FontDesc[128];
 
+void set_font_css(const char *fdesc, char *fdcss)
+{
+    char *fstretch[9] = {"ultra-condensed", "extra-condensed", "condensed",
+        "semi-condensed", "normal", "semi-expanded", "expanded",
+        "extra-expanded", "ultra-expanded"};
+    char *fstyle[3] = {"normal", "oblique", "italic"};
+    PangoFontDescription *pfd = pango_font_description_from_string(fdesc);
+    snprintf(fdcss, 511, "textview { font-family: %s; font-size: %upx; "
+            "font-stretch: %s; font-weight: %u; font-style: %s; }",
+            pango_font_description_get_family(pfd),
+            pango_font_description_get_size(pfd) / 1000,
+            fstretch[pango_font_description_get_stretch(pfd)],
+            pango_font_description_get_weight(pfd),
+            fstyle[pango_font_description_get_style(pfd)]);
+    pango_font_description_free(pfd);
+}
+
 static gboolean on_match_select(GtkEntryCompletion *widget, GtkTreeModel *model,
         GtkTreeIter *iter, gpointer user_data)
 {  
@@ -224,31 +241,19 @@ void create_main_window()
     btConjg = gtk_button_new_with_mnemonic(_("conjugate"));
     gtk_widget_show(btConjg);
     gtk_box_pack_start(GTK_BOX(hbox1), btConjg, FALSE, FALSE, 0);
-#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
-    gtk_button_set_focus_on_click(GTK_BUTTON(btConjg), FALSE);
-#else
     gtk_widget_set_focus_on_click(btConjg, FALSE);
-#endif
 
     btFont = gtk_button_new_with_label("Aa");
     gtk_widget_set_tooltip_text (btFont, _("Set font"));
     gtk_widget_show(btFont);
     gtk_box_pack_end(GTK_BOX(hbox1), btFont, FALSE, FALSE, 0);
-#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
-    gtk_button_set_focus_on_click(GTK_BUTTON(btFont), FALSE);
-#else
     gtk_widget_set_focus_on_click(btFont, FALSE);
-#endif
 
     btCommon = gtk_check_button_new_with_label("Br");
     gtk_widget_set_tooltip_text (btCommon, _("Conjugate verbs as ordinary Brazilians do"));
     gtk_widget_show(btCommon);
     gtk_box_pack_end(GTK_BOX(hbox1), btCommon, FALSE, FALSE, 0);
-#if GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION < 20
-    gtk_button_set_focus_on_click(GTK_BUTTON(btCommon), FALSE);
-#else
     gtk_widget_set_focus_on_click(btCommon, FALSE);
-#endif
 
     scrolledwindow1 = gtk_scrolled_window_new(NULL, NULL);
     gtk_widget_show(scrolledwindow1);
@@ -319,7 +324,7 @@ void create_main_window()
                 if(FontDesc[i] == '\n' || FontDesc[i] == '\r')
                     FontDesc[i] = 0;
             char fdcss[512];
-            snprintf(fdcss, 511, "GtkTextView { font: %s; }", FontDesc);
+            set_font_css(FontDesc, fdcss);
 
             GtkCssProvider *provider = gtk_css_provider_new();
             GdkDisplay *display = gdk_display_get_default();
@@ -335,4 +340,3 @@ void create_main_window()
 
     gtk_widget_show(mainWindow);
 }
-
